abacusai.model_monitor_version — AbacusAI documentation

# `abacusai.model_monitor_version`

## Module Contents

### Classes

`ModelMonitorVersion` | A version of a model monitor

class abacusai.model_monitor_version.ModelMonitorVersion(client, modelMonitorVersion=None, status=None, modelMonitorId=None, monitoringStartedAt=None, monitoringCompletedAt=None, trainingFeatureGroupVersion=None, predictionFeatureGroupVersion=None, error=None, pendingDeploymentIds=None, failedDeploymentIds=None, metricConfigs=None, metricTypes=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A version of a model monitor

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - modelMonitorVersion (str) – The unique identifier of a model monitor version.

    - status (str) – The current status of the model.

    - modelMonitorId (str) – A reference to the model monitor this version belongs to.

    - monitoringStartedAt (str) – The start time and date of the monitoring process.

    - monitoringCompletedAt (str) – The end time and date of the monitoring process.

    - trainingFeatureGroupVersion (unique string identifiers) – Feature group version IDs that this refresh pipeline run is monitoring.

    - predictionFeatureGroupVersion (unique string identifiers) – Feature group version IDs that this refresh pipeline run is monitoring.

    - error (str) – Relevant error if the status is FAILED.

    - pendingDeploymentIds (list) – List of deployment IDs where deployment is pending.

    - failedDeploymentIds (list) – List of failed deployment IDs.

    - metricConfigs (json field) – List of metric configs for the model monitor instance.

    - metricTypes (dict) – List of metric types.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict

  get_prediction_drift()

    Gets the label and prediction drifts for a model monitor.

    Parameters

      model_monitor_version (str) – The unique identifier to a model monitor version created under the project.

    Returns

      An object describing training and prediction output label and prediction distributions.

    Return type

      DriftDistributions

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns

      The current object

    Return type

      ModelMonitorVersion

  describe()

    Retrieves a full description of the specified model monitor version

    Parameters

      model_monitor_version (str) – The unique version ID of the model monitor version

    Returns

      A model monitor version.

    Return type

      ModelMonitorVersion

  delete()

    Deletes the specified model monitor version.

    Parameters

      model_monitor_version (str) – The ID of the model monitor version to delete.

  metric_data(metric_type)

    Returns the data needed for decile metrics associated with the model monitor.

    Parameters

      metric_type (str) –

  get_model_monitoring_logs(stdout=False, stderr=False)

    Returns monitoring logs for the model.

    Parameters

      - stdout (bool) – Set True to get info logs

      - stderr (bool) – Set True to get error logs

    Returns

      A function logs.

    Return type

      FunctionLogs

  get_drift_for_feature(feature_name)

    Gets the feature drift associated with a single feature in an output feature group from a prediction.

    Parameters

      feature_name (str) – Name of the feature to view the distribution of.

  get_outliers_for_feature(feature_name=None)

    Gets a list of outliers measured by a single feature (or overall) in an output feature group from a prediction.

    Parameters

      feature_name (str) – Name of the feature to view the distribution of.

  wait_for_monitor(timeout=1200)

    A waiting call until model monitor version is ready.

    Parameters

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Gets the status of the model monitor version.

    Returns

      A string describing the status of the model monitor version, for e.g., pending, complete, etc.

    Return type

      str